@@ -345,7 +345,8 @@ impl Cell {
     ) -> CellResult<()> {
         use holochain_p2p::event::HolochainP2pEvent::*;
         match evt {
-            PutAgentInfoSigned { .. }
+            KGenReq { .. }
+            | PutAgentInfoSigned { .. }
             | GetAgentInfoSigned { .. }
             | QueryAgentInfoSigned { .. }
             | QueryGossipAgents { .. }
@@ -813,7 +814,7 @@ impl Cell {
         let signal_tx = self.signal_broadcaster().await;
         let ribosome = self.get_ribosome().await?;
         let invocation =
-            ZomeCallInvocation::from_interface_call(self.conductor_api.clone(), call).await;
+            ZomeCallInvocation::try_from_interface_call(self.conductor_api.clone(), call).await?;
 
         let args = CallZomeWorkflowArgs {
             cell_id: self.id.clone(),
