@@ -728,7 +728,9 @@ pub mod test {
             {
                 let mut count = 0;
                 for env in p2p.lock().values() {
-                    count += env.conn().unwrap().p2p_list_agents().unwrap().len();
+                    let mut conn = env.conn().unwrap();
+                    let txn = conn.transaction().unwrap();
+                    count += txn.p2p_list_agents().unwrap().len();
                 }
                 count
             },
