@@ -1,11 +1,14 @@
 use hdk::prelude::*;
 use holochain::conductor::config::ConductorConfig;
-use holochain::sweettest::SweetNetwork;
+use holochain::sweettest::{SweetConductor, SweetNetwork, SweetZome};
 use holochain::sweettest::{SweetConductorBatch, SweetDnaFile};
 use holochain::test_utils::host_fn_caller::Post;
 use holochain::test_utils::wait_for_integration_1m;
 use holochain::test_utils::wait_for_integration_with_others_10s;
 use holochain::test_utils::WaitOps;
+use holochain_sqlite::db::{DbKindT, DbWrite};
+use holochain_state::prelude::fresh_reader_test;
+use unwrap_to::unwrap_to;
 
 #[derive(serde::Serialize, serde::Deserialize, Debug, SerializedBytes, derive_more::From)]
 #[serde(transparent)]
@@ -281,3 +284,171 @@ async fn sharded_consistency() {
         ElementEntry::Present(Entry::app(().try_into().unwrap()).unwrap())
     );
 }
+
+#[cfg(feature = "test_utils")]
+#[tokio::test(flavor = "multi_thread")]
+async fn private_entries_dont_leak() {
+    use holochain::test_utils::consistency_10s;
+
+    let _g = observability::test_run().ok();
+    let mut entry_def = EntryDef::default_with_id("entrydef");
+    entry_def.visibility = EntryVisibility::Private;
+
+    #[derive(Serialize, Deserialize, Debug, SerializedBytes)]
+    struct PrivateEntry;
+
+    let zome = InlineZome::new_unique(vec![entry_def.clone()])
+        .callback("create", move |api, _: ()| {
+            let entry_def_id: EntryDefId = entry_def.id.clone();
+            let entry = Entry::app(PrivateEntry {}.try_into().unwrap()).unwrap();
+            let hash = api.create(CreateInput::new(
+                entry_def_id,
+                entry,
+                ChainTopOrdering::default(),
+            ))?;
+            Ok(hash)
+        })
+        .callback("get", |api, hash: AnyDhtHash| {
+            api.get(vec![GetInput::new(hash, GetOptions::default())])
+                .map_err(Into::into)
+        })
+        .callback("get_details", |api, hash: AnyDhtHash| {
+            api.get_details(vec![GetInput::new(hash, GetOptions::default())])
+                .map_err(Into::into)
+        });
+
+    let mut conductors = SweetConductorBatch::from_standard_config(2).await;
+
+    let (dna_file, _) = SweetDnaFile::unique_from_inline_zome("zome1", zome)
+        .await
+        .unwrap();
+    let dnas = vec![dna_file];
+
+    let apps = conductors.setup_app("app", &dnas).await.unwrap();
+
+    let ((alice,), (bobbo,)) = apps.into_tuples();
+
+    conductors.exchange_peer_info().await;
+    // Call the "create" zome fn on Alice's app
+    let hash: HeaderHash = conductors[0].call(&alice.zome("zome1"), "create", ()).await;
+
+    consistency_10s(&[&alice, &bobbo]).await;
+
+    let entry_hash =
+        EntryHash::with_data_sync(&Entry::app(PrivateEntry {}.try_into().unwrap()).unwrap());
+
+    check_all_gets_for_private_entry(
+        &conductors[0],
+        &alice.zome("zome1"),
+        hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+    check_all_gets_for_private_entry(
+        &conductors[1],
+        &bobbo.zome("zome1"),
+        hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+
+    // Bobbo creates the same private entry.
+    let bob_hash: HeaderHash = conductors[1].call(&bobbo.zome("zome1"), "create", ()).await;
+    consistency_10s(&[&alice, &bobbo]).await;
+
+    check_all_gets_for_private_entry(
+        &conductors[0],
+        &alice.zome("zome1"),
+        hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+    check_all_gets_for_private_entry(
+        &conductors[1],
+        &bobbo.zome("zome1"),
+        hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+
+    check_all_gets_for_private_entry(
+        &conductors[0],
+        &alice.zome("zome1"),
+        bob_hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+    check_all_gets_for_private_entry(
+        &conductors[1],
+        &bobbo.zome("zome1"),
+        bob_hash.clone(),
+        entry_hash.clone(),
+    )
+    .await;
+
+    check_for_private_entries(alice.dht_env().clone());
+    check_for_private_entries(conductors[0].get_cache_env(alice.cell_id()).unwrap());
+    check_for_private_entries(bobbo.dht_env().clone());
+    check_for_private_entries(conductors[1].get_cache_env(bobbo.cell_id()).unwrap());
+}
+
+fn check_for_private_entries<Kind: DbKindT>(env: DbWrite<Kind>) {
+    let count: usize = fresh_reader_test(env, |txn| {
+        txn.query_row(
+            "select count(header.rowid) from header join entry on header.entry_hash = entry.hash where private_entry = 1",
+            [],
+            |row| row.get(0),
+        )
+        .unwrap()
+    });
+    assert_eq!(count, 0);
+}
+
+async fn check_all_gets_for_private_entry(
+    conductor: &SweetConductor,
+    zome: &SweetZome,
+    header_hash: HeaderHash,
+    entry_hash: EntryHash,
+) {
+    let mut elements: Vec<Option<Element>> = conductor
+        .call(zome, "get", AnyDhtHash::from(header_hash.clone()))
+        .await;
+    let e: Vec<Option<Element>> = conductor
+        .call(zome, "get", AnyDhtHash::from(entry_hash.clone()))
+        .await;
+    elements.extend(e);
+    let details: Vec<Option<Details>> = conductor
+        .call(zome, "get_details", AnyDhtHash::from(header_hash.clone()))
+        .await;
+    elements.extend(
+        details
+            .into_iter()
+            .map(|d| d.map(|d| unwrap_to!(d => Details::Element).clone().element)),
+    );
+    let elements = elements.into_iter().filter_map(|a| a).collect();
+    check_elements_for_private_entry(zome.cell_id().agent_pubkey().clone(), elements);
+    let entries: Vec<Option<Details>> = conductor
+        .call(zome, "get_details", AnyDhtHash::from(entry_hash.clone()))
+        .await;
+    for entry in entries {
+        let entry = match entry {
+            Some(e) => e,
+            None => continue,
+        };
+        let details = unwrap_to!(entry=> Details::Entry).clone();
+        let headers = details.headers;
+        for header in headers {
+            assert_eq!(header.header().author(), zome.cell_id().agent_pubkey());
+        }
+    }
+}
+
+fn check_elements_for_private_entry(caller: AgentPubKey, elements: Vec<Element>) {
+    for element in elements {
+        if *element.header().author() == caller {
+            assert_ne!(*element.entry(), ElementEntry::Hidden);
+        } else {
+            assert_eq!(*element.entry(), ElementEntry::Hidden);
+        }
+    }
+}
